@@ -1,7 +1,6 @@
 import dataclasses
 import json
 import logging
-import re
 import sys
 from enum import Enum
 from typing import List, Dict, Iterable
@@ -62,9 +61,10 @@ class RestBackend:
 
     def add_object_load_policy(self, bo_name, properties: List[str]):
         object_policy = self._get_object_load_policy_for_bo(bo_name)
+        objs_props = object_policy.setdefault('properties', [])
         for prop in properties:
-            if not any(p for p in object_policy.get('properties', []) if p['name'] == prop):
-                object_policy['properties'].append({'name': prop})
+            if not any(p for p in objs_props if p['name'] == prop):
+                objs_props.append({'name': prop})
 
     def clear_object_load_policy(self, bo_name):
         self.policy['types'] = list(t for t in self.policy['types'] if t['name'] != bo_name)
