@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import AssemblyArrangement, BusinessObject, Folder, ItemRevision, CFMOverrideEntry, BOMWindow, RevisionRule, ImanFile, Item, Fnd0ProductSessionData
+from tcsoa.gen.BusinessObjects import BusinessObject, ImanFile, AssemblyArrangement, Fnd0ProductSessionData, RevisionRule, Folder, CFMOverrideEntry, BOMWindow, Item, ItemRevision
 from typing import Dict, List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 from datetime import datetime
 
