@@ -2,7 +2,7 @@ from tcsoa.gen.Cae._2012_02.services import StructureManagementService as imp0
 from tcsoa.gen.Cae._2014_06.services import StructureManagementService as imp1
 from tcsoa.gen.Cae._2011_06.services import SimulationProcessManagementService as imp2
 from tcsoa.gen.Cae._2013_12.services import SimulationProcessManagementService as imp3
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class StructureManagementService(TcService):
