@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.Configuration._2010_04.SmartUiBldr import ListValuesForComponentsResponse, ForTypePreferences, GetPropertiesForSelectionsResponse, ListObjectsForComponentsResponse, GetResultForSelectionsResponse, ComponentInfo, ListForerunnersForComponentsResponse, GetValuesForComponentResponse, CurrentSelectionsMap
+from tcsoa.gen.Configuration._2010_04.SmartUiBldr import GetValuesForComponentResponse, ComponentInfo, ForTypePreferences, ListObjectsForComponentsResponse, CurrentSelectionsMap, ListForerunnersForComponentsResponse, GetPropertiesForSelectionsResponse, ListValuesForComponentsResponse, GetResultForSelectionsResponse
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class SmartUiBldrService(TcService):
