@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import BusinessObject, BOMLine, BOMWindow, Dataset, ImanFile
+from tcsoa.gen.BusinessObjects import BOMLine, ImanFile, BusinessObject, Dataset, BOMWindow
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
