@@ -1,9 +1,9 @@
 from __future__ import annotations
 
-from tcsoa.gen.BusinessObjects import BOMWindow, Item, Effectivity, ItemRevision
+from tcsoa.gen.BusinessObjects import BOMWindow, Item, ItemRevision, Effectivity
 from typing import List
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcBaseObj
+from tcsoa.base import TcBaseObj
 from dataclasses import dataclass
 
 
