@@ -1,5 +1,5 @@
 from tcsoa.gen.Internal_ProjectManagementAw._2019_12.services import ScheduleManagementAwService as imp0
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class ScheduleManagementAwService(TcService):
