@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.TCXMLImportExport._2020_12.Briefcase import ExportObjectsToBriefcaseInput, ImportObjectsFromBriefcaseInput
+from tcsoa.gen.Internal.TCXMLImportExport._2020_12.Briefcase import ImportObjectsFromBriefcaseInput, ExportObjectsToBriefcaseInput
 from tcsoa.gen.Server import ServiceData
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class BriefcaseService(TcService):
