@@ -1,7 +1,7 @@
 from tcsoa.gen.Internal_VendorManagementAW._2019_12.services import VendorManagementService as imp0
 from tcsoa.gen.Internal_VendorManagementAW._2020_05.services import VendorManagementService as imp1
 from tcsoa.gen.Internal_VendorManagementAW._2020_12.services import VendorManagementService as imp2
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class VendorManagementService(TcService):
