@@ -1,7 +1,7 @@
 from __future__ import annotations
 
-from tcsoa.gen.Internal.XlsBom._2020_12.Import import ImportExcelResp, StructureInfoResp, ImportExcelData, ExcelImportInput
-from tcsoa.utils import TcService
+from tcsoa.gen.Internal.XlsBom._2020_12.Import import ImportExcelData, StructureInfoResp, ImportExcelResp, ExcelImportInput
+from tcsoa.base import TcService
 
 
 class ImportService(TcService):
