@@ -1,8 +1,8 @@
 from __future__ import annotations
 
-from tcsoa.gen.Notification._2014_10.SubscriptionManagement import SubscriptionsResponse, GetSubscriptionsCriteriaInput, SubscriptionInput, FindSubscriptionsCriteriaInput, ModifySubscriptionInput
+from tcsoa.gen.Notification._2014_10.SubscriptionManagement import SubscriptionInput, FindSubscriptionsCriteriaInput, ModifySubscriptionInput, SubscriptionsResponse, GetSubscriptionsCriteriaInput
 from typing import List
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class SubscriptionManagementService(TcService):
