@@ -3,7 +3,7 @@ from tcsoa.gen.Vendormanagement._2008_06.services import VendorManagementService
 from tcsoa.gen.Vendormanagement._2007_06.services import VendorManagementService as imp2
 from tcsoa.gen.Vendormanagement._2012_02.services import VendorManagementService as imp3
 from tcsoa.gen.Vendormanagement._2016_09.services import VendorManagementService as imp4
-from tcsoa.utils import TcService
+from tcsoa.base import TcService
 
 
 class VendorManagementService(TcService):
